@@ -265,6 +265,13 @@ class SessionAdapterTests(base.TestCase):
                           self.url,
                           content=six.u('unicode'))
 
+    def test_dont_pass_empty_string_as_content(self):
+        self.assertRaises(TypeError,
+                          self.adapter.register_uri,
+                          'GET',
+                          self.url,
+                          content=six.u(''))
+
     def test_dont_pass_bytes_as_text(self):
         if six.PY2:
             self.skipTest('Cannot enforce byte behaviour in PY2')
@@ -275,6 +282,16 @@ class SessionAdapterTests(base.TestCase):
                           self.url,
                           text=six.b('bytes'))
 
+    def test_dont_pass_empty_string_as_text(self):
+        if six.PY2:
+            self.skipTest('Cannot enforce byte behaviour in PY2')
+
+        self.assertRaises(TypeError,
+                          self.adapter.register_uri,
+                          'GET',
+                          self.url,
+                          text=six.b(''))
+
     def test_dont_pass_non_str_as_content(self):
         self.assertRaises(TypeError,
                           self.adapter.register_uri,
@@ -357,7 +374,7 @@ class SessionAdapterTests(base.TestCase):
         self.assertTrue(self.adapter.called)
         self.assertFalse(m.called_once)
 
-    def test_adapter_picks_correct_adatper(self):
+    def test_adapter_picks_correct_adapter(self):
         good = '%s://test3.url/' % self.PREFIX
         self.adapter.register_uri('GET',
                                   '%s://test1.url' % self.PREFIX,
